@@ -8,7 +8,7 @@ use File::Path qw( make_path );
 use Dist::Zilla::MintingProfile::Author::Plicease;
 
 # ABSTRACT: add author only release tests to xt/release
-our $VERSION = '0.97'; # VERSION
+our $VERSION = '0.98'; # VERSION
 
 
 with 'Dist::Zilla::Role::BeforeBuild';
@@ -71,7 +71,7 @@ sub before_build
 pod_spelling_system:
   # list of words that are spelled correctly
   # (regardless of what spell check thinks)
-  stop_words: []
+  stopwords: []
 
 pod_coverage:
   # format is "Class#method" or "Class", regex allowed
@@ -100,7 +100,7 @@ Dist::Zilla::Plugin::Author::Plicease::Tests - add author only release tests to
 
 =head1 VERSION
 
-version 0.97
+version 0.98
 
 =head1 SYNOPSIS
 
